==============
API Extensions
==============

API extensions is the standard way of introducing new functionality
to the Tacker project, it allows plugins to determine if they wish
to support the functionality or not.

Examples
========

The easiest way to demonstrate how an API extension is written, is
by studying an existing API extension and explaining the different layers.

.. seealso::

   https://docs.openstack.org/api-ref/nfv-orchestration/
